==> totoui-0.3.0.tgz: package/lib/tabsimple.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _tabsimpleItemJsx = require('./tabsimpleItem.js');

var _tabsimpleItemJsx2 = _interopRequireDefault(_tabsimpleItemJsx);

var Tabs = (function (_React$Component) {
    _inherits(Tabs, _React$Component);

    function Tabs(props) {
        _classCallCheck(this, Tabs);

        _get(Object.getPrototypeOf(Tabs.prototype), 'constructor', this).call(this, props);
        this.state = {
            active: this.props.active || 0
        };
    }

    _createClass(Tabs, [{
        key: 'getActiveKey',
        value: function getActiveKey() {
            return this.state.active;
        }
    }, {
        key: 'handleTouch',
        value: function handleTouch(tab, index) {
            var self = this;
            this.setState({
                active: index
            }, function () {
                self.props.getActiveIndex();
            });
        }
    }, {
        key: 'render',
        value: function render() {
            var tabs = [],
                className = 'tab-trigger ',
                active = this.state.active;
            var tabContents = _react2['default'].Children.map(this.props.children, function (tab, index) {
                var classes = undefined,
                    isActive = active === index;
                var onHandleTouch = this.handleTouch.bind(this, tab, index);

                classes = className + (isActive ? 'active' : '');

                tabs.push(_react2['default'].createElement(
                    'li',
                    { className: classes, onClick: onHandleTouch, key: index },
                    _react2['default'].createElement(
                        'a',
                        { href: "#" },
                        tab.props.label
                    )
                ));

                return _react2['default'].createElement(_tabsimpleItemJsx2['default'], {
                    key: index,
                    active: isActive,
                    _child: tab.props.children });
            }, this);

            return _react2['default'].createElement(
                'div',
                { className: "tabs" },
                _react2['default'].createElement(
                    'div',
                    { className: "tabs-nav" },
                    _react2['default'].createElement(
                        'ul',
                        null,
                        tabs
                    )
                ),
                _react2['default'].createElement(
                    'div',
                    { className: "tabs-body" },
                    tabContents
                )
            );
        }
    }]);

    return Tabs;
})(_react2['default'].Component);

Tabs.propTypes = {
    initialCount: _react2['default'].PropTypes.number
};

Tabs.defaultProps = {
    initialCount: 0
};

module.exports = Tabs;

==> totoui-0.5.1.tgz: package/lib/tabsimple.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _tabsimpleItemJsx = require('./tabsimpleItem.js');

var _tabsimpleItemJsx2 = _interopRequireDefault(_tabsimpleItemJsx);

var Tabs = (function (_React$Component) {
    _inherits(Tabs, _React$Component);

    function Tabs(props) {
        _classCallCheck(this, Tabs);

        _get(Object.getPrototypeOf(Tabs.prototype), 'constructor', this).call(this, props);
        this.state = {
            active: this.props.active || 0
        };
    }

    _createClass(Tabs, [{
        key: 'getActiveKey',
        value: function getActiveKey() {
            return this.state.active;
        }
    }, {
        key: 'handleTouch',
        value: function handleTouch(tab, index) {
            var self = this;
            this.setState({
                active: index
            }, function () {
                self.props.getActiveIndex();
            });
        }
    }, {
        key: 'render',
        value: function render() {
            var tabs = [],
                className = 'tab-trigger ',
                active = this.state.active;
            var tabContents = _react2['default'].Children.map(this.props.children, function (tab, index) {
                var classes = undefined,
                    isActive = active === index;
                var onHandleTouch = this.handleTouch.bind(this, tab, index);

                classes = className + (isActive ? 'active' : '');

                tabs.push(_react2['default'].createElement(
                    'li',
                    { className: classes, onClick: onHandleTouch, key: index },
                    _react2['default'].createElement(
                        'a',
                        { href: '#' },
                        tab.props.label
                    )
                ));

                return _react2['default'].createElement(_tabsimpleItemJsx2['default'], {
                    key: index,
                    active: isActive,
                    _child: tab.props.children });
            }, this);

            return _react2['default'].createElement(
                'div',
                { className: 'tabs' },
                _react2['default'].createElement(
                    'div',
                    { className: 'tabs-nav' },
                    _react2['default'].createElement(
                        'ul',
                        null,
                        tabs
                    )
                ),
                _react2['default'].createElement(
                    'div',
                    { className: 'tabs-body' },
                    tabContents
                )
            );
        }
    }]);

    return Tabs;
})(_react2['default'].Component);

Tabs.propTypes = {
    initialCount: _react2['default'].PropTypes.number
};

Tabs.defaultProps = {
    initialCount: 0
};

module.exports = Tabs;
